@@ -16,7 +16,7 @@ import asyncio
 from enum import Enum
 from itertools import chain
 import logging
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Iterator, Tuple, cast
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Iterator, cast
 
 from xknx.dpt.dpt_color import XYYColor
 from xknx.remote_value import (
@@ -473,7 +473,7 @@ class Light(Device):
         )
         if None in colors:
             return None, self.white.brightness.value
-        return cast(Tuple[int, int, int], colors), self.white.brightness.value
+        return cast(tuple[int, int, int], colors), self.white.brightness.value
 
     async def set_color(
         self, color: tuple[int, int, int], white: int | None = None
