@@ -32,7 +32,7 @@ class SearchResponse(KNXIPBody):
 
     def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
-        return HPAI.LENGTH + sum([dib.calculated_length() for dib in self.dibs])
+        return HPAI.LENGTH + sum(dib.calculated_length() for dib in self.dibs)
 
     def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
@@ -51,13 +51,11 @@ class SearchResponse(KNXIPBody):
                 return dib.name
         return "UNKNOWN"
 
-    def to_knx(self) -> list[int]:
+    def to_knx(self) -> bytes:
         """Serialize to KNX/IP raw data."""
-        data = []
-        data.extend(self.control_endpoint.to_knx())
-        for dib in self.dibs:
-            data.extend(dib.to_knx())
-        return data
+        return self.control_endpoint.to_knx() + b"".join(
+            dib.to_knx() for dib in self.dibs
+        )
 
     def __str__(self) -> str:
         """Return object as readable string."""
